# OSIsoft Cloud Services Python Library Sample

**Version:** 0.1.16_preview

[![Build Status](https://dev.azure.com/osieng/engineering/_apis/build/status/product-readiness/OCS/osisoft.sample-ocs-sample_libraries-python?branchName=master)](https://dev.azure.com/osieng/engineering/_build/latest?definitionId=2622&branchName=master)

The python OCS library is an introductory language-specific examples of programming against OSISoft Cloud Services ([OCS](https://www.osisoft.com/Solutions/OSIsoft-Cloud-Services/)). It is as instructional samples only and are not for production use.

They can be obtained by running: pip install ocs_sample_library_preview

The library is not intended to show every endpoint and every option/parameter for endpoints it has. The library is known to be incomplete.

Other language libraries and samples are available on [Github](https://github.com/osisoft/OSI-Samples).

Tests are done by testing the sample apps that use this.

Developed against Python 3.7.2.

[OSI Samples](https://github.com/osisoft/OSI-samples) are licensed under the Apache 2 license.

For the main OCS sample libraries page on master [ReadMe](https://github.com/osisoft/OSI-Samples-OCS/blob/master/docs/SAMPLE_LIBRARIES_README.md)  
For the main OCS samples page on master [ReadMe](https://github.com/osisoft/OSI-Samples-OCS)  
For the main OSIsoft samples page on master [ReadMe](https://github.com/osisoft/OSI-Samples)
